@@ -30,7 +30,7 @@ if __name__ == '__main__':
     # producing the same file order, but this is unlikely, if not
     # as unlikely as in the above test.
     if 'aslr' in captures:
-        output.append(id(__name__))
+        output.append(id("teststring123"))
     if 'environment' in captures:
         output.extend("%s=%s" % pair for pair in os.environ.items())
     if 'build_path' in captures:
