@@ -11,8 +11,8 @@ from reprotest.shell_syn import *
 
 
 def test_basic():
-    assert (sanitize_globs("""lol \$ *"\$ s" "" '' ' ' " " '   '   "" """)
-        == '''./lol ./\$ ./*"\$ s" ./"" ./'' ./' ' ./" " ./'   ' ./""''')
+    assert (sanitize_globs("""lol \\$ *"\\$ s" "" '' ' ' " " '   '   "" """)
+        == '''./lol ./\\$ ./*"\\$ s" ./"" ./'' ./' ' ./" " ./'   ' ./""''')
     assert (sanitize_globs("""*"*"'*' ../hm wut???""")
         == '''./*"*"'*' ./../hm ./wut???''')
 
@@ -30,6 +30,7 @@ def test_basic():
     assert sanitize_globs('-rf') == './-rf'
     assert sanitize_globs('/') == './/'
 
+
 def test_shlex_quote():
     for _ in range(65536):
         x = ''.join(random.choice(string.printable) for _ in range(random.randint(0, 32)))
